@@ -67,8 +67,8 @@ int main (int argc, char *argv[]) {
 	int *the_product_id_stral = NULL;
 	int num_product_ids = 0;
 	char * client_ipaddr = NULL;
-	char c;
-	int err;
+	int c;
+	int err = 0;
 	int i;
 
 	opterr = 0;
@@ -240,11 +240,11 @@ int main (int argc, char *argv[]) {
 	} else if (err == GEOIP_LICENSE_KEY_INVALID_ERR) {
 		fprintf(stderr,"Invalid License Key in %s - Please visit http://maxmind.com/ for a subscription\n",license_file);
 	} else if (err == GEOIP_USER_ID_INVALID_ERR){
-		fprintf(stderr,"Invalid UserID");
+		fprintf(stderr,"Invalid UserID\n");
 	} else if (err == GEOIP_PRODUCT_ID_INVALID_ERR){
-		fprintf(stderr,"Invalid product ID or subscription expired");
+		fprintf(stderr,"Invalid product ID or subscription expired\n");
 	} else if (err < 0) {
-		fprintf(stderr,"Received Error %d when attempting to update GeoIP Database\n",err);
+		fprintf(stderr,"Received Error %d (%s) when attempting to update GeoIP Database\n",err, GeoIP_get_error_message(err));
 	} else {
 		fprintf(stderr,"Updated database(s).\n");
 	}
