@@ -34,7 +34,7 @@ int main () {
 	for (i = 0; i < 2; ++i) {
 		if (0 == i) {
 			/* Read from filesystem, check for updated file */
-			gi = GeoIP_open("../data/GeoIP.dat", GEOIP_STANDARD & GEOIP_CHECK_CACHE);
+			gi = GeoIP_open("../data/GeoIP.dat", GEOIP_STANDARD | GEOIP_CHECK_CACHE);
 		} else {
 			/* Read from memory, faster but takes up more memory */
 			gi = GeoIP_open("../data/GeoIP.dat", GEOIP_MEMORY_CACHE);
@@ -85,6 +85,7 @@ int main () {
 			}
 			test_num++;
 		}
+		fclose(f);
 
 		f = fopen("country_test2.txt","r");
 		while (fscanf(f, "%s", ipAddress) != EOF) {
@@ -96,6 +97,7 @@ int main () {
 			}
 			test_num++;
 		}
+		fclose(f);
 
 		f = fopen("country_test_name.txt","r");
 		while (fscanf(f, "%s", ipAddress) != EOF) {
